@@ -16,24 +16,30 @@ module TomlRB
       keys = symbolize_keys ? @dotted_keys.map(&:to_sym) : @dotted_keys
       update = keys.reverse.inject(visit_value(@value)) { |k1, k2| {k2 => k1} }
 
+      parent_inline_table = fully_defined_keys.find { |k| dotted_keys_str.start_with?("#{k}.") }
+      fail ValueOverwriteError.new(@dotted_keys.first) if parent_inline_table
+
       if @value.is_a?(InlineTable)
+        child_keys_exist = fully_defined_keys.find { |k| k.start_with?("#{dotted_keys_str}.") }
+        fail ValueOverwriteError.new(@dotted_keys.first) if child_keys_exist
+
+        existing_hash = hash.dig(*keys)
+        fail ValueOverwriteError.new(@dotted_keys.first) if existing_hash.is_a?(Hash) && !existing_hash.empty?
+
         fully_defined_keys << dotted_keys_str
-        hash.merge!(update) { |key, _, _| fail ValueOverwriteError.new(key) }
-      elsif fully_defined_keys.find { |k| update.dig(*k) }
-        hash.merge!(update) { |key, _, _| fail ValueOverwriteError.new(key) }
-      else
-        dotted_key_merge(hash, update)
       end
+
+      dotted_key_merge(hash, update)
     end
 
     def dotted_key_merge(hash, update)
-      hash.merge!(update) { |key, old, new|
+      hash.merge!(update) do |key, old, new|
         if old.is_a?(Hash) && new.is_a?(Hash)
           dotted_key_merge(old, new)
         else
           fail ValueOverwriteError.new(key)
         end
-      }
+      end
     end
 
     def accept_visitor(parser)
