@@ -8,9 +8,16 @@ module TomlRB
       ensure_key_not_defined(visited_keys)
       current = hash
       keys = symbolize_keys ? @dotted_keys.map(&:to_sym) : @dotted_keys
-      keys.each do |key|
+      keys.each_with_index do |key, index|
         current[key] = {} unless current.key?(key)
         element = current[key]
+
+        # If this is the final key and it's already an array (from [[key]]), that's invalid
+        is_final_key = (index == keys.length - 1)
+        if is_final_key && element.is_a?(Array)
+          fail ValueOverwriteError.new(key)
+        end
+
         current = element.is_a?(Array) ? element.last : element
         # check that key has not been defined before as a scalar value
         fail ValueOverwriteError.new(key) unless current.is_a?(Hash)
@@ -18,18 +25,20 @@ module TomlRB
       current
     end
 
-    # Fail if the key was already defined with a ValueOverwriteError
-    def ensure_key_not_defined(visited_keys)
-      fail ValueOverwriteError.new(full_key) if visited_keys.include?(full_key)
-      visited_keys << full_key
-    end
-
     def accept_visitor(parser)
       parser.visit_table self
     end
 
     def full_key
-      @dotted_keys.join('.')
+      @dotted_keys.join(".")
+    end
+
+    private
+
+    # Fail if the key was already defined with a ValueOverwriteError
+    def ensure_key_not_defined(visited_keys)
+      fail ValueOverwriteError.new(full_key) if visited_keys.include?(full_key)
+      visited_keys << full_key
     end
   end
 
